@@ -9,7 +9,7 @@ module Config
   DESTDIR = '' if not defined? DESTDIR
   CONFIG = {}
   TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.6/i386\-msdosdjgpp\Z', '')
-  CONFIG["srcdir"] = "/pub/ruby/16/dist/ruby-1.6.8/ruby16"
+  CONFIG["srcdir"] = "/pub/ruby/16/ruby16"
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "ruby"
   CONFIG["EXEEXT"] = ".exe"
@@ -28,8 +28,8 @@ module Config
   CONFIG["sysconfdir"] = "$(prefix)/etc"
   CONFIG["sharedstatedir"] = "$(prefix)/com"
   CONFIG["localstatedir"] = "$(prefix)/var"
-  CONFIG["libdir"] = "/usr/local/i586-pc-msdosdjgpp/lib"
-  CONFIG["includedir"] = "/usr/local/i586-pc-msdosdjgpp/include"
+  CONFIG["libdir"] = "$(exec_prefix)/lib"
+  CONFIG["includedir"] = "$(prefix)/include"
   CONFIG["oldincludedir"] = "/usr/include"
   CONFIG["infodir"] = "$(prefix)/info"
   CONFIG["mandir"] = "$(prefix)/man"
@@ -79,7 +79,7 @@ module Config
   CONFIG["STRIP"] = "strip"
   CONFIG["EXTSTATIC"] = ""
   CONFIG["setup"] = "Setup.dj"
-  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/16/dist/ruby-1.6.8/d.obj -rfake"
+  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/16/djgpp -rfake"
   CONFIG["PREP"] = "fake.rb"
   CONFIG["LIBRUBY_LDSHARED"] = "ld"
   CONFIG["LIBRUBY_DLDFLAGS"] = ""
@@ -91,18 +91,20 @@ module Config
   CONFIG["LIBRUBY"] = "$(LIBRUBY_A)"
   CONFIG["LIBRUBYARG"] = "$(LIBRUBY_A)"
   CONFIG["SOLIBS"] = ""
-  CONFIG["DLDLIBS"] = "-lc"
+  CONFIG["DLDLIBS"] = ""
   CONFIG["ENABLE_SHARED"] = "no"
   CONFIG["MAINLIBS"] = ""
   CONFIG["arch"] = "i386-msdosdjgpp"
   CONFIG["sitedir"] = "$(prefix)/lib/ruby/site_ruby"
-  CONFIG["configure_args"] = "--includedir=/usr/local/i586-pc-msdosdjgpp/include --libdir=/usr/local/i586-pc-msdosdjgpp/lib --target=i386-msdosdjgpp --host=i586-pc-msdosdjgpp --build=i586-pc-linux-gnu --with-opt-dir=/usr/local/i586-pc-msdosdjgpp --cache=./config.cache"
+  CONFIG["configure_args"] = "--cache=config.cache --program-prefix= --target=i386-msdosdjgpp --host=i586-pc-msdosdjgpp --build=i586-pc-linux-gnu"
+  CONFIG["NROFF"] = "/usr/bin/nroff"
+  CONFIG["MANTYPE"] = "doc"
   CONFIG["ruby_version"] = "$(MAJOR).$(MINOR)"
   CONFIG["rubylibdir"] = "$(libdir)/ruby/$(ruby_version)"
   CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
   CONFIG["sitearchdir"] = "$(sitelibdir)/$(arch)"
-  CONFIG["compile_dir"] = "/pub/ruby/16/dist/ruby-1.6.8/d.obj"
+  CONFIG["compile_dir"] = "/pub/ruby/16/djgpp"
   MAKEFILE_CONFIG = {}
   CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
   def Config::expand(val)
